<?php
    /*********************************************************************************
     * Zurmo is a customer relationship management program developed by
     * Zurmo, Inc. Copyright (C) 2012 Zurmo Inc.
     *
     * Zurmo is free software; you can redistribute it and/or modify it under
     * the terms of the GNU General Public License version 3 as published by the
     * Free Software Foundation with the addition of the following permission added
     * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
     * IN WHICH THE COPYRIGHT IS OWNED BY ZURMO, ZURMO DISCLAIMS THE WARRANTY
     * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
     *
     * Zurmo is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
     * details.
     *
     * You should have received a copy of the GNU General Public License along with
     * this program; if not, see http://www.gnu.org/licenses or write to the Free
     * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
     * 02110-1301 USA.
     *
     * You can contact Zurmo, Inc. with a mailing address at 113 McHenry Road Suite 207,
     * Buffalo Grove, IL 60089, USA. or at email address contact@zurmo.com.
     ********************************************************************************/

    // KEEP these in alphabetical order.
    // KEEP them indented correctly.
    // KEEP all the language files up-to-date with each other.
    // DON'T MAKE A MESS!
    return array(
        '(Unknown)'
            => '(Desconocido)',
        '(Unnamed)'
            => '(Sin Nombre)',
        '2D Donut Chart'
            => 'Anillo',
        '2D Horizontal Bar Graph'
            => 'Bares',
        '2D Pie Chart'
            => 'Gráfico circular 2D',
        '2D Vertical Bar Graph'
            => 'Histograma 2D',
        '3D Pie Chart'
            => 'Gráfico circular 3D',
        '3D Vertical Bar Graph'
            => 'Histograma 3D',
        '<strong>Zurmo</strong> is a <strong>Customer Relationship Management</strong> system by <strong>Zurmo Inc.</strong>'
            => '<strong>Zurmo</strong> es un systema de <strong>Customer Relationship Management</strong> de <strong>Zurmo Inc.</strong>',
        '<strong>Zurmo</strong> is licensed under the GPLv3.  You can read the license <a href="http://www.zurmo.org/license">here</a>.'
            => '<strong>Zurmo</strong> está licenciado bajo la licencia GPLv3. Usted puede leer la licencia <a href="http://www.zurmo.org/license">aquí</a>.',
        '<strong>Zurmo</strong> uses the following great Open Source tools and frameworks:'
            => '<strong>Zurmo</strong> utiliza las siguientes herramientas de Open Source y frameworks:',
        'A large amount of data has been requested for export.  You will receive a notification with the download link when the export is complete.'
            => 'Una gran cantidad de datos se ha solicitado para la exportación. Recibirá una notificación con el enlace de descarga cuando la exportación se ha completado.',
        'About Zurmo'
            => 'Sobre Zurmo',
        'Access Administration Tab'
            => 'Acceso a Administración',
        'Access Currency Configuration'
            => 'Acceso a Divisas',
        'Access Developer Tools'
            => 'Acceda a Herramientas para Desarrolladores',
        'Access Failure'
            => 'Falta de acceso',
        'Access Global Configuration'
            => 'Acceso a la Configuración Global',
        'Access Groups Tab'
            => 'Acceso a Grupos',
        'Access Roles Tab'
            => 'Acceso a Roles',
        'Active'
            => 'Activo',
        'Active currencies can be used when creating new records and as a default currency for a user.'
            => 'Divisas activos se pueden utilizar al crear nuevos registros, y como una divisa predeterminada para un usuario.',
        'Active languages can be used by users. The system language and any language in use by a user cannot be inactivated'
            => 'Idiomas activos pueden ser utilizados por los usuarios. El idioma del sistema y de cualquier idioma utilizado por un usuario no puede ser desactivado.',
        'Ad-hoc / Owner'
            => 'Ad-hoc / Propietario',
        'Add Comment'
            => 'Añadir comentario',
        'Add criteria'
            => 'Añadir criterios',
        'Add Currency'
            => 'Añadir divisa',
        'Add new fields, remove ones you don\'t need and change the layout using Designer.'
            => 'Añadir nuevos campos, eliminar los no necesita y cambiar el diseño con el Diseñador.',
        'Address'
            => 'Dirección',
        'Admin'
            => 'Admin', // Same Word Translated
        'Alert'
            => 'Alerta',
        'Allow'
            => 'Permitir',
        'Amount'
            => 'Suma',
        'An error has occurred. Please click'
            => 'Ha ocurrido un error. Por favor, haga clic',
        'An error occured during login. Please try again.'
            => 'Error de login. Por favor, inténtalo de nuevo.',
        'Any City'
            => 'Ciudad',
        'Any Country'
            => 'País',
        'Any Email Address'
            => 'Dirección de email',
        'Any Invalid Email'
            => 'Email inválida',
        'Any Opted Out Email'
            => 'Email opt-out',
        'Any Postal Code'
            => 'Código postal',
        'Any State'
            => 'Estado',
        'Any Street'
            => 'Calle',
        'Application is in maintenance mode, and only Super Administrators can access it.'
            => 'La aplicación es en modo de mantenimiento, y sólo los administradores de Super tiene acceso.',
        'Application is in maintenance mode. Please try again later.'
            => 'La aplicación es en modo de mantenimiento. Por favor, inténtelo de nuevo más tarde.',
        'Application Name'
            => 'Nombre de systema',
        'are required.'
            => 'son obligatorios.',
        'Are you number one{spaceAndFirstName}? Find out how you size up to your colleagues on the Leaderboard.'
            => '¿Es el número uno {spaceAndFirstName}? Compárese con sus colegas en la tabla clasificatoria.',
        'Are you sure you want to delete this group?'
            => '¿Está seguro que desea eliminar este grupo?',
        'Are you sure you want to delete this role?'
            => '¿Está seguro que desea eliminar este role?',
        'Attachment'
            => 'Adjunto',
        'Attachments'
            => 'Adjuntos',
        'Audit Event'
            => 'Lista de modificaciones',
        'Audit Trail'
            => 'Log de modificaciones',
        'Automotive'
            => 'Automóvil',
        'Banking'
            => 'Bancario',
        'Business Services'
            => 'Servicios de negocios',
        'by {ownerStringContent}'
            => 'de {ownerStringContent}',
        'Cache has been successfully cleaned.'
            => 'Caché se ha limpiado correctamente.',
        'Changes to active currencies saved successfully.'
            => 'Divisas activas cambiado con éxito.',
        'Changes to active languages saved successfully.'
            => 'Idiomas activos cambiado con éxito.',
        'Chart Type'
            => 'Tipo de gráfico',
        'City'
            => 'Ciudad',
        'Clear Cache'
            => 'Borrar caché',
        'Click on the Map link on records to see the customer location on Google Maps.'
            => 'Haga clic en el enlace para ver el mapa de localización con Google Maps.',
        'Close'
            => 'Cerrar',
        'Code'
            => 'Código',
        'Comment'
            => 'Comentar',
        'Configuration'
            => 'Configuración',
        'Configure'
            => 'Configurar',
        'Convert'
            => 'Convertir',
        'Copyright &#169; Zurmo Inc., 2012. All Rights reserved.'
            => 'Copyright &#169; Zurmo Inc. de 2012. Todos los derechos reservados.',
        'Could not remove relation.'
            => 'No se puede eliminar la relación.',
        'Could not save relation.'
            => 'No se puede guardar la relación.',
        'Could not use this API call for HAS_ONE relationships.'
            => 'Imposible utilizar esta llamada a la API para las relaciones HAS_ONE.',
        'Country'
            => 'Pais',
        'Create Group'
            => 'Crear grupo',
        'Create Groups'
            => 'Crear grupos',
        'Create Role'
            => 'Crear role',
        'Create Roles'
            => 'Crear roles',
        'Created'
            => 'Creado',
        'created by {ownerStringContent}'
            => 'creado por {ownerStringContent}',
        'Criteria Selected <span class="icon-clear">Z</span>'
            => 'Criterios Seleccionados <span class="icon-clear">Z</span>',
        'Currencies: Create'
            => 'Divisas: crear',
        'Currencies: List'
            => 'Divisas: listar',
        'Currency'
            => 'Divisa',
        'Currency Configuration'
            => 'Configuración de divisas',
        'Currency in use.'
            => 'Divisa en uso',
        'Currency Rates Update Job'
            => 'Actualiza el tipo de cambio',
        'Currency Value'
            => 'Valor de divisa',
        'Custom data updated successfully.'
            => 'Datos personalizados se ha actualizado correctamente.',
        'Customer'
            => 'Cliente',
        'Dashboard portlet list page size'
            => 'Cantidad de elementos que figuran en el portlet',
        'Data'
            => 'Datos',
        'Database upgrade not completed. Please try again later.'
            => 'La actualización de la base de datos no se ha completado. Por favor, inténtelo de nuevo más tarde.',
        'days'
            => 'Días',
        'Dead'
            => 'Muerto',
        'Decide who can view and edit a record, set Group rights and permissions.'
            => 'Decidir quién puede ver y editar un registro, establecer los derechos de grupo y los permisos.',
        'Delete Group'
            => 'Eliminar grupo',
        'Delete Groups'
            => 'Eliminar grupos',
        'Delete Role'
            => 'Eliminar role',
        'Delete Roles'
            => 'Eliminar roles',
        'Deny'
            => 'Denegar',
        'Department'
            => 'Departamento',
        'Description'
            => 'Descripción',
        'Developer Tools'
            => 'Herramientas para Desarrolladores',
        'Dr.'
            => 'Dr.', // Same Word Translated
        'Due On'
            => 'Fecha de vencimiento',
        'Edit charts on the dashboard by clicking the config icon in the top right of each portlet.'
            => 'Haga clic en el icono de configuración en la parte superior derecha de cada portlet para editar gráficos en el salpicadero.',
        'Email'
            => 'Email', // Same Word Translated
        'Email Address'
            => 'Dirección de email',
        'Enable game notification popup'
            => 'Activar la notificación popup de juego',
        'Energy'
            => 'Energía',
        'Event Name'
            => 'Nombre de evento',
        'every'
            => 'cada',
        'Everyone'
            => 'Todo el Mundo',
        'Fields with'
            => 'Los campos con',
        'File Content'
            => 'Contenido de archivo',
        'File failed to upload. The file is empty.'
            => 'Archivo no se pudo cargar. El archivo está vacío.',
        'Files'
            => 'Archivos',
        'Filter By Created User'
            => 'Filtrar la lista por Creado por',
        'Filtered Lists'
            => 'Listas filtradas',
        'Financial Services'
            => 'Servicios Financieros',
        'Find what you need quickly using the global search at the top of the screen.'
            => 'Utilice la búsqueda global en la parte superior de la pantalla para encontrar rápidamente lo que necesita.',
        'First Name'
            => 'Primer nombre',
        'Forums'
            => 'Foros',
        'Global and Basic Search Fields'
            => 'Campos de búsqueda global y simples',
        'Global Configuration'
            => 'Configuración global',
        'Global configuration saved successfully.'
            => 'Configuración global guardado con éxito.',
        'Global search'
            => 'Búsqueda Global',
        'Go to Search'
            => 'Ir a la búsqueda',
        'Got questions{spaceAndFirstName}? Find answers in the Zurmo Wiki.'
            => '¿Tiene alguna pregunta{spaceAndFirstName}? Lea el Zurmo Wiki.',
        'Group'
            => 'Grupo',
        'Group Module Permissions'
            => 'Permisos',
        'Group Policies'
            => 'Reglas de Seguridad',
        'Group Rights'
            => 'Derechos de grupo',
        'Groups'
            => 'Grupos',
        'Groups Home'
            => 'Inicio de Grupos',
        'here'
            => 'aquí',
        'Home'
            => 'Inicio',
        'If there is new metadata to load using CustomManagement, use this option.'
            => 'Si hay nuevos metadatos a cargar con CustomManagement, utilice esta opción.',
        'In Progress'
            => 'En progreso',
        'In the case where you have reloaded the database, some cached items might still exist. This is a way to clear that cache.'
            => 'Si hay nuevos metadatos a cargar con CustomManagement, utilice esta opción. En caso que haya recargado la base de datos, algunos elementos almacenados en caché aún puedan existir. Esta es una manera de limpiar esa caché.',
        'Inbound Call'
            => 'Llamada entrante',
        'Incorrect username or password.'
            => 'Nombre de usuario o contraseña incorrecta.',
        'Industry'
            => 'Industria',
        'Inherited - All'
            => 'Heredar - Todos',
        'Inherited - Allow'
            => 'Heredar - Permitir',
        'Inherited - Deny'
            => 'Heredar - Denegar',
        'Inherited - No'
            => 'Heredar - No',
        'Inherited - Owner Only'
            => 'Heredar - propietario sólo',
        'Inherited - Yes'
            => 'Heredar - Sí',
        'Inherited Value:'
            => 'Valor heredado:',
        'Insurance'
            => 'Seguros',
        'Invalid currency code'
            => 'Código de divisa inválido',
        'Invalid username or password.'
            => 'El nombre de usuario o contraseña no es válido.',
        'Is Invalid'
            => 'Es inválido',
        'Job Title'
            => 'Título',
        'Label must be all lowercase.'
            => 'Etiqueta debe ser todo minúsculo.',
        'Label must not be empty.'
            => 'Etiqueta no debe ser vacío.',
        'Label must not contain any special characters.'
            => 'La etiqueta no debe contener caracteres especiales.',
        'Language'
            => 'Lengua',
        'Languages'
            => 'Idiomas',
        'Languages: List'
            => 'Idiomas: Lista',
        'Last Name'
            => 'Apellido',
        'Last Updated'
            => 'Última actualización',
        'Latitude'
            => 'Latitud',
        'Let Zurmo crunch the numbers, add calculated fields to your records in Designer.'
            => 'Permite Zurmo para hacer el trabajo duro, agregar campos calculados en el Diseñador.',
        'List Filters'
            => 'Filtros de lista',
        'List page size'
            => 'Número de elementos en la vista de lista',
        'List View'
            => 'Vista de lista',
        'Load'
            => 'Cargar',
        'Load a saved search'
            => 'Cargar una búsqueda guardada',
        'Longitude'
            => 'Longitud',
        'Manage Active Languages'
            => 'Administrar idiomas activos',
        'Manage Currency Configuration'
            => 'Administrar la configuración de divisas',
        'Manage Global Configuration'
            => 'Administrar la configuración global',
        'Manage Groups'
            => 'Administrar grupos',
        'Manage Roles'
            => 'Administrar roles',
        'Manufacturing'
            => 'Manufactura',
        'map'
            => 'mapa',
        'Member'
            => 'Miembro',
        'Member Of'
            => 'Miembro de',
        'Members'
            => 'Miembros',
        'Menu'
            => 'Menú',
        'Missing Record'
            => 'Archivo falta',
        'Missing Required Fields'
            => 'Los campos obligatorios se colocará en el punto de vista',
        'Mobile Phone'
            => 'Tel. móvil',
        'Model was not created.'
            => ' El modelo no fue creado.',
        'Model was not updated.'
            => 'El modelo no ha sido actualizado.',
        'Model was updated, but there were issues with relations.'
            => 'Modelo se ha actualizado, pero hubo problemas con las relaciones.',
        'Modify Structure'
            => 'Cambiar la estructura',
        'Module Name - Plural'
            => 'Nombre del módulo - Plural',
        'Module Name - Plural (lowercase)'
            => 'Nombre del módulo - Plural (en minúsculas)',
        'Module Name - Singular'
            => 'Nombre del módulo - Singular',
        'Module Name - Singular (lowercase)'
            => 'Nombre del módulo - Singular (en minúsculas)',
        'Module Permissions'
            => 'Permisos de módulo',
        'Module Permissions Saved Successfully.'
            => 'Permisos de módulo guardado correctamente.',
        'Mr.'
            => 'Sr.',
        'Mrs.'
            => 'Sra.',
        'Ms.'
            => 'Srta.',
        'My List Configuration View'
            => 'Mi vista de lista configuración',
        'Need help{spaceAndFirstName}, why not ask a question in the forum?'
            => 'Necesita ayuda{spaceAndFirstName}, ¿por qué no hacer una pregunta en el foro?',
        'Need to see the big picture? Click Roll-Up to see activities from related records.'
            => 'Activar el Rollup para ver todas las actividades relacionadas.',
        'Need to update multiple records at once? Select them from the list and hit the Update button.'
            => '¿Se necesita actualizar registros múltiples? Seleccione de la lista y pulsa el botón Actualizar.',
        'Never'
            => 'Nunca',
        'New'
            => 'Nuevo',
        'No Results Found'
            => 'No se encontraron resultados',
        'Non Members'
            => 'No miembres',
        'Not Set'
            => 'Predeterminado',
        'Not Set - Ad-hoc / Owner'
            => 'Predeterminado - Ad-hoc / Propietario',
        'Notifications'
            => 'Notificaciones',
        'Office Fax'
            => 'Fax de la oficina',
        'Office Phone'
            => 'Teléfono de la Oficina',
        'Oh no!'
            => 'Oh no!', // Same Word Translated
        'Once a day, early in the morning.'
            => 'Una vez al día, por la mañana temprano.',
        'Once a week, early in the morning.'
            => 'Una vez a la semana, por la mañana temprano.',
        'Only Items I Own'
            => 'Sólo mis elementos',
        'Opt Out'
            => 'Opt out',
        'owned by {ownerStringContent}'
            => 'propiedad de {ownerStringContent}',
        'Owner'
            => 'Propietario',
        'Owner and users in'
            => 'Propietario y usuarios en',
        'Owner Only'
            => 'Propietario sólo',
        'Parent Group'
            => 'Parent group',
        'Parent Role'
            => 'Parent role',
        'Parlez vous Français{spaceAndFirstName}? Choose your preferred language in your My Profile area.'
            => 'Seleccione su idioma preferido en mi perfil.',
        'Password'
            => 'Contraseña',
        'Permissions'
            => 'Permisos',
        'Permitable'
            => 'Permitable', // Same Word Translated
        'Please provide data.'
            => 'Por favor, facilite los datos.',
        'Please resolve the following issues for {modelString}:'
            => 'Por favor, resolver los siguientes problemas para {modelString}',
        'Please use FireFox, Chrome, or Internet Explorer.'
            => 'Por favor, use Firefox, Chrome, o Internet Explorer.',
        'Policies'
            => 'Reglas',
        'Policies Saved Successfully.'
            => 'Reglas guardado correctamente.',
        'Popup list page size'
            => 'Número de elementos en la lista popup',
        'Post to Profile'
            => 'Publicar en el perfil ',
        'Postal Code'
            => 'Código postal',
        'Primary Address'
            => 'Dirección principal',
        'Primary Email'
            => 'Email principal',
        'Qualified'
            => 'Calificado',
        'Rate to'
            => 'Tipo de cambio a',
        'Rate To Base'
            => 'Tipo de cambio base',
        'Read'
            => 'Leer',
        'Read permissions rebuild complete.'
            => 'Reconstrucción de permisis lectura completo.',
        'Recently Viewed'
            => 'Visto recientemente',
        'Recently Viewed lets you jump back to any records you have looked at lately.'
            => 'Vistos Recientemente trae de vuelta a los registros que se han visto recientemente.',
        'Recycled'
            => 'Reciclado',
        'Remember me next time'
            => 'Recordarme la próxima vez',
        'Remember{spaceAndFirstName}, the Audit Trail shows you what has changed on a record and who changed it.'
            => 'El registro de actualización muestra la historia de cambios, incluyendo el nombre de usuario que ha cambiado.',
        'Retail'
            => 'Negocio al por menor',
        'Return to Admin Menu'
            => 'Volver al menú de administración',
        'Rights'
            => 'Derechos',
        'Rights and Permissions'
            => 'Permisos y derechos de seguridad',
        'Rights Saved Successfully.'
            => 'Derechos guardado correctamente.',
        'Role'
            => 'Role', // Same Word Translated
        'Roles'
            => 'Roles', // Same Word Translated
        'Roles Home'
            => 'Inicio de Roles',
        'Run'
            => 'Ejecutar',
        'Salutation'
            => 'Saludo',
        'Save Changes'
            => 'Guardar cambios',
        'Save search'
            => 'Guardar búsqueda',
        'Save yourself time and click the pencil icon to jump right in and edit your record.'
            => 'Haga clic en el icono del lápiz para editar rápidamente.',
        'Search'
            => 'Buscar',
        'Search by name, phone, or e-mail'
            => 'Buscar por nombre, teléfono, o e-mail',
        'Secondary Address'
            => 'Dirección secundaria',
        'Secondary Email'
            => 'Email secundaria',
        'Securable Item'
            => 'Artículo asegurable',
        'Security Overview'
            => 'Seguridad',
        'See more search results by clicking the down arrow at the bottom of the screen.'
            => 'Haga clic en la flecha hacia abajo para mostrar más resultados de búsqueda.',
        'Select a field'
            => 'Seleccione un campo',
        'Select a Group'
            => 'Seleccione un grupo',
        'Select a Parent Group'
            => 'Seleccione un grupo de padres',
        'Select a Parent Role'
            => 'Seleccione un role de padres',
        'Select a Role'
            => 'Seleccione un role',
        'Self-Generated'
            => 'Autogenerado',
        'Send a test email to'
            => 'Enviar un mensaje de prueba a',
        'Set your preferences, password, and contact details in your My Profile area.'
            => 'Cambiar las preferencias de usuario, contraseña y datos de contacto en mi perfil.',
        'Settings'
            => 'Configuración',
        'Shipping Address'
            => 'Dirección de envío',
        'Sign in'
            => 'Iniciar sesión',
        'Sign in required.'
            => 'Inicio de sesión requerido.',
        'Sign out'
            => 'Salir',
        'Sign out failed.'
            => 'Error de salido.',
        'Size'
            => 'Tamaño',
        'skipped because you do not have sufficient permissions.'
            => 'Omitido porque no tiene los permisos necesarios.',
        'Sorry! Your browser is not supported.'
            => '¡Lo siento! Su navegador no es compatible.',
        'Source'
            => 'Fuente',
        'Specified custom field name was invalid.'
            => 'El nombre del campo personalizado no es válido.',
        'Stage'
            => 'Etapa',
        'Standard Fields'
            => 'Campos standards',
        'State'
            => 'Estado',
        'Status'
            => 'Estatus',
        'Street 1'
            => 'Calle 1',
        'Street 2'
            => 'Calle 2',
        'Sublist page size'
            => 'Número de elementos de la sublista',
        'Successfully updated'
            => 'Actualizado correctamente',
        'Summary'
            => 'Sumario',
        'Super Administrators'
            => 'Superadministradores',
        'Tag Cloud fields allow you to tag records with values so that you can easily find them later.'
            => 'Los campos de Nube de palabras permite asociar palabras clave con sus datos para poder recuperarlos fácilmente.',
        'Technology'
            => 'Tecnología',
        'The currency rate web service says this currency code is invalid even though zurmo says it is valid. The rate could not be automatically updated.'
            => 'El servicio web para los tipos de cambio indica que este código de divisa no es válida, aunque zurmo indica que es válida. El tipo de cambio no puede ser actualizado automáticamente',
        'The currency rate web service was unavailable. The rate could not be automatically updated.'
            => 'El servicio web para los tipos de cambio no estaba disponible. El tipo de cambio no puede ser actualizado automáticamente.',
        'The currency was not removed because it is in use.'
            => 'La moneda no se ha eliminado porque está en uso.',
        'The default value is {policyDefault}'
            => 'El valor predeterminado es {policyDefault}?',
        'The ID specified was invalid.'
            => ' ID no válido.',
        'The Import Wizard helps get your data into the system easily, find it under the config icon (that\'s the cog in the top right).'
            => 'El Asistente de importación le permite importar fácilmente tus datos en el sistema. Busque el icono en la configuración situado en la esquina superior derecha.',
        'The Notifications speech bubble keeps you up to date on important events.'
            => 'La burbuja de diálogo Notificaciones le mantiene actualizado sobre los eventos importantes.',
        'The record you are trying to access does not exist.'
            => 'El registro que está intentando acceder no existe.',
        'The related model ID specified was invalid.'
            => 'El ID de modelo relacionado especificado no es válido.',
        'The status specified is invalid.'
            => 'El estatus especificado no es válido.',
        'There are no recently viewed items.'
            => 'No hay elementons recientemente vistos',
        'There are required fields missing from the following layout: {view}.  Please contact your administrator.'
            => 'Campos obligatorios faltan en la siguiente diseño: {vista}. Por favor, contacte con su administrador.',
        'There is no data to export.'
            => 'No hay datos para exportar.',
        'This action is only available in debug mode.'
            => 'Esta acción sólo está disponible en modo debug.',
        'This is <strong>version {zurmoVersion}</strong> of <strong>Zurmo</strong>.'
            => 'Está utilizando el <strong>version {zurmoVersion}</strong> de <strong>Zurmo</strong>.',
        'This name is reserved. Please pick a different name.'
            => 'Este nombre está reservado. Por favor, elija un nombre distinto.',
        'Time zone'
            => 'Zona horaria',
        'Title'
            => 'Título',
        'to continue to the home page. If the error persists please contact your administrator.'
            => 'para continuar a la página de inicio. Si el error persiste, por favor comuníquese con el administrador.',
        'Tradeshow'
            => 'Feria comercial',
        'Type a currency code or name to search.'
            => 'Escriba un código de divisa o nombre para buscar',
        'Unsupported action.'
            => 'Acción no compatible.',
        'Update'
            => 'Actualizar',
        'Update Custom Data'
            => 'Actualizar los datos personalizados',
        'Updated'
            => 'Actualizado',
        'Upload attachments to a record by clicking "More Options" when adding a note.'
            => 'Puedes subir archivos adjuntos a un registro haciendo clic en "Más opciones", al añadir una nota.',
        'User Membership'
            => 'Miembros del grupo',
        'User Membership Saved Successfully.'
            => 'Miembros del grupo guardado con éxito.',
        'Username'
            => 'Usuario',
        'Users'
            => 'Users',
        'Value'
            => 'Valor',
        'Values'
            => 'Valores',
        'Visit <strong>Zurmo Inc.</strong> at {url}.'
            => 'Visitar <strong>Zurmo Inc.</strong> en {url}',
        'Visit the <strong>Zurmo Open Source Project</strong> at {url}.'
            => 'Visitar el <strong>Proyecto Zurmo Open Source</strong> en {url}.',
        'Want to export your data directly to Excel? Search for the data you need and hit the Export button.'
            => 'Para exportar los datos a Excel, realizar una búsqueda y haga clic en "Exportar".',
        'Website'
            => 'Sitio web',
        'Welcome'
            => 'Bienvenidos',
        'What is this?'
            => '¿Qué es esto?',
        'Who can read and write'
            => 'Permiso de lectura / escritura',
        'Who can read and write - Default'
            => 'Permiso de lectura / escritura',
        'Word of Mouth'
            => 'Boca en boca',
        'Write'
            => 'Escribir',
        'You can add relations only for HAS_MANY and MANY_MANY relations.'
            => 'Usted puede agregar sólo un tipo de relaciones HAS_MANY y MANY_MANY.',
        'You have tried to access a page you do not have access to.'
            => 'Ha intentado acceder a una página que no tiene acceso.',
        'You must have at least one active currency.'
            => 'Debe tener al menos una divisa activa.',
        'Your RedBean version is currentVersion and it should be acceptableVersion.'
            => 'Su versión de RedBean es currentVersion y debe ser acceptableVersion.',
        'Your Yii version is currentVersion and it should be acceptableVersion.'
            => 'Su versión de Yii es currentVersion y debe ser acceptableVersion',
        'ZurmoCRM'
            => 'ZurmoCRM', // Same Word Translated
        '{modelString} is already connected to this record.'
            => '{modelString} ya está conectado a este registro.',
        '{url} (installed with Yii)'
            => '{url} (instalado con Yii)',
        '{url} (version {version} is installed)'
            => '{url} (version {version} es instalado)',
    );
?>
